"use strict";

import transform from 'css-to-react-native';
import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const baseStyles = StyleSheet.create({
  scrollView: {
    flex: 1,
    minHeight: 20
  },
  codeContainer: {
    padding: 16,
    minWidth: '100%'
  },
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  },
  token: {
    fontFamily: monospaceFont,
    fontSize: 14
  }
});
const ALLOWED_STYLE_PROPERTIES = {
  color: true,
  background: true,
  backgroundColor: true,
  fontWeight: true,
  fontStyle: true
};
function cleanStyle(style) {
  const styles = Object.entries(style).filter(([key]) => ALLOWED_STYLE_PROPERTIES[key]).map(([key, value]) => [key, value]);
  return transform(styles);
}
export function getRNStylesFromShikiStyle(theme) {
  if (!theme?.tokenColors) return {};
  const styles = {
    editor: cleanStyle({
      backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e',
      color: theme.colors?.['editor.foreground'] || '#d4d4d4'
    })
  };
  theme.tokenColors.forEach(token => {
    if (!token.settings || !token.scope) return;
    const style = cleanStyle(token.settings);
    const scopes = Array.isArray(token.scope) ? token.scope : [token.scope];
    scopes.forEach(scope => {
      styles[scope] = style;
    });
  });
  return styles;
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const {
    tokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme
  });
  const themeStyles = useMemo(() => getRNStylesFromShikiStyle(theme), [theme]);
  const renderToken = (token, rowIndex, tokenIndex) => {
    const tokenStyle = cleanStyle({
      color: token.color || themeStyles.editor?.color,
      fontStyle: token.fontStyle ? 'italic' : 'normal',
      fontWeight: token.fontStyle ? 'bold' : 'normal'
    });
    return /*#__PURE__*/_jsx(Text, {
      style: [baseStyles.token, tokenStyle, textStyle, {
        fontSize
      }],
      children: token.content
    }, `${rowIndex}-${tokenIndex}`);
  };
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [baseStyles.scrollView, themeStyles.editor, scrollViewProps?.style],
    contentContainerStyle: [baseStyles.codeContainer, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, rowIndex) => /*#__PURE__*/_jsx(View, {
        style: baseStyles.lineContainer,
        children: line.map((token, tokenIndex) => renderToken(token, rowIndex, tokenIndex))
      }, rowIndex))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map